# geogo: Interactive Map for hurricane analysis 🌀🌎


[![image](https://img.shields.io/pypi/v/geogo.svg)](https://pypi.python.org/pypi/geogo)
[![image](https://img.shields.io/conda/vn/conda-forge/geogo.svg)](https://anaconda.org/conda-forge/geogo)
[![image](docs/GEOGO.png)](https://github.com/jlhammel/geogo)


**A python package for geospatial analysis and mapping**


-   Free software: MIT License
-   Documentation: https://jlhammel.github.io/geogo
-   Geogo is a Python package meant for climatologists to analyze hurricane data from HURDAT2. Geogo uses ipyleaflet to create interactive maps for analysis. This package will allow you to use WMS, raster, geojson, image, and video files to further understand the impact of past hurricanes. Using interactive maps, hurricane track data from the Python package tropycal, and NASA GIBS data, the user can track the hurricane and analyze the landscape around the impacted areas.

## Features

- Process geospatial data
- Track past hurricanes impacting the Americas
- Analyse hurricanes using images, raster, video, WMS, and geojson files